[![CC BY-NC-SA 4.0][cc-by-nc-sa-shield]][cc-by-nc-sa]

# Dataset EmoProgress: Cumulated Emotion Progression Analysis in Dreams and Customer Service Dialogues
## Table of Contents
1. Overview
2. Citation
3. Content folders
4. Details dataset
5. License
6. Contact


## 1. Overview
This folder contains the EmoProgress text corpus. In EmoProgress, the data is annotated along a novel annotation methodology by revealing textual parts step-by-step, thus reflecting the emotional state _up to a certain part_. Our methodology is applied to two different domains, namely customer service interactions and dreams. More details on the data and methods can be found in the associated paper "EmoProgress: Cumulated Emotion Progression Analysis in Dreams and Customer Service Dialogues" by Eileen Wemmer, Sofie Labat and Roman Klinger, accepted at LREC-COLING 2024 (see citation below).


## 2. Citation
If you use this dataset in your work, please cite our paper as follows:
```
@InProceedings{wemmer_labat_klinger_2024,
  author    = {Wemmer, Eileen and Labat, Sofie and Klinger, Roman},
  title     = {EmoProgress: Cumulated Emotion Progression Analysis in Dreams and Customer Service Dialogues},
  booktitle      = {Proceedings of The Joint International Conference on Computational Linguistics, Language Resources and Evaluation (LREC-COLING)},
  month          = {May},
  year           = {2024},
  address        = {Torino, Italy},
  publisher      = {European Language Resources Association}
}
```


## 3. Content folders
The main folder contains the following files and subfolders:
* `README.md`: this file
* `cs`: the customer service dataset
* `dreams`: the dream dataset

The folders CS and Dream each have two files: 
* `<domain>_texts.csv`: the split texts
* `<domain>_annotations.csv`: the corresponding annotations


# 4. Details dataset
`dreams_texts.csv` contains 49 dreams, split into sentences.
`cs_texts.csv` contains 339 CS dialogues, split into bi-turns (one operator turn followed by one customer turn).

Both files contain the fields:
* `IID`: An instance identifier to match instances to annotations
* `1-10`: ID of the part (either sentence or bi-turn), chronologically ordered

In `dreams_annotations.csv` and `cs_annotations.csv`, each line constitutes one full set of annotations for one instance made by one annotator.
Annotations contain the following columns:

* `IID`: An instance identifier to match instances to annotations. Some instances were labelled by more than one annotator, therefore some IIDs occure more than once.

* `ANNO_ID`: Annotator ID. Annotator IDs are fixed within domain (CS or dreams), but not between domains. This means that two dreams annotated by annotator 2 are labelled by the same person, yet both a dream and CS dialogue annotated by annotator 2 are not neccessarily labelled by the same person. Annotator ID tuples for inter-annotator agreement (IAA) measures are [(36, 39), (35, 38), (34, 37), (44, 47), (45, 49), (46, 48)] for CS and [(25, 28), (26, 29), (27, 30), (38, 41), (39, 43), (40, 42)] for dreams.

* `CAT_<part>`: Ten colums with categorical ratings. Part numbering starts at 1 and ends at 10. For example, the categorical label for the second sentece/bi-turn can be found in column CAT_2. Categories are encoded as numbers and can be interpreted as follows:
	* `1`:	joy
	* `2`:	admiration
	* `3`:	gratitude
	* `4`:	relief
	* `5`:	desire
	* `6`:	fear
	* `7`:	anger/annoyance
	* `8`:	sadness/disappointment
	* `9`:	surprise/confusion
	* `10`:	neutral

* `CONF`: One confidence rating per instance per annotator. Values range between 1 (not at all confident) and 5 (extremely confident). -9 indicates that the question was skipped.

* `<appraisal>_<part>`: Ten columns per Appraisal Dimension.
Part numbering starts at 1 and ends at 10. For example, the label for pleasentness in the second sentence/bi-turn can be found in *PLEAS_2*.
Values range between 1 (not at all) and 5 (extremely).
Appraisal dimensions are encoded as follows:
    * `PLEAS`: Pleasantness
    * `FAM`: Familiarity
    * `EFF`: Effort
    * `OWNRES`: Own Responsibility
    * `OTHRES`: Others' Responsibility
    * `CHACONT`: Chance Control
    * `ATT`: Attention
    * `CONSANT`: Consequence Anticipation
    * `OWNCONT`: Own Control
    * `EVEPRED`: Event Predictability


# 5. License
This work is licensed under a [Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License][cc-by-nc-sa]. 
This means that the repository is freely available for academic purposes or individual research, but any other use is 
explicitly prohibited. Moreover, any derivative work (e.g., re-using or modifying the existing dataset) has to be 
distributed under the same terms and conditions. If you want to use the data for commercial purposes, please contact the 
authors (see contact details below).

[cc-by-nc-sa]: http://creativecommons.org/licenses/by-nc-sa/4.0/
[cc-by-nc-sa-image]: https://licensebuttons.net/l/by-nc-sa/4.0/88x31.png
[cc-by-nc-sa-shield]: https://img.shields.io/badge/License-CC%20BY--NC--SA%204.0-lightgrey.svg


# 6. Contact
For any questions regarding the dataset, do not hesitate to contact us at:
- [eileen.wemmer@iat.uni-stuttgart.de](eileen.wemmer@iat.uni-stuttgart.de)
- [sofie.labat@ugent.be](sofie.labat@ugent.be)
- [roman.klinger@uni-bamberg.de](roman.klinger@uni-bamberg.de)
